==> crm-commom-vo-1.1.9.37.release.jar: com/biz/crm/nebular/dms/rebatefeepool/RebateFeePoolDetailLogVo.java <==
package com.biz.crm.nebular.dms.rebatefeepool;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmExtVo;
import com.biz.crm.nebular.mdm.CrmFileVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.math.BigDecimal;
import java.util.List;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 折扣费用池条目调整明细VO
 * @Author: chenrong
 * @Date: 2020/11/23 16:53
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel(value = "折扣费用池条目调整明细VO")
public class RebateFeePoolDetailLogVo extends CrmExtVo {

  private static final long serialVersionUID = -4941737089772063724L;

  /**
   * 折扣费用池条目编码
   */
  @ApiModelProperty(value = "折扣费用池条目编码")
  private String rebateFeePoolDetailCode;

  /**
   * 折扣费用池条目调整明细编码
   */
  @ApiModelProperty(value = "折扣费用池条目调整明细编码")
  private String code;

  /**
   * 调整类型
   */
  @ApiModelProperty(value = "调整类型")
  private Integer adjustType;

  @ApiModelProperty(value = "调整类型名称")
  @CrmDict(typeCode="fee_adjust_type",dictCodeField="adjustType")
  private String adjustTypeName;

  /**
   * 业务来源编码
   */
  @ApiModelProperty(value = "业务来源编码")
  private String resourceCode;

  /**
   * 调整金额
   */
  @ApiModelProperty(value = "调整金额")
  private BigDecimal adjustFee = BigDecimal.ZERO;

  /**
   * 支付方式
   */
  @ApiModelProperty(value = "支付方式")
  private Integer payType;

  /**
   * 冗余字段，文件对象集合
   */
  @ApiModelProperty(value = "冗余字段，文件对象集合")
  private List<RebateFeePoolFileVo> files;

  /**
   * 折扣费用池条目
   */
  @ApiModelProperty(value = "折扣费用池条目")
  private RebateFeePoolDetailVo rebateFeePoolDetailVo;

  /**
   * 冻结金额
   */
  @ApiModelProperty(value = "冻结金额")
  private BigDecimal frozenFee = BigDecimal.ZERO;

  /**
   * 冗余字段：折扣费用池编码
   */
  @ApiModelProperty(value = "折扣费用池编码")
  private String rebateFeePoolCode;

  /**
   * 冗余字段：调整类型集合
   */
  @ApiModelProperty(value = "调整类型集合，pc端查报表传参用")
  private List<String> adjustTypes;

  /**
   * 本次上账金额
   */
  private BigDecimal onAccountFee = BigDecimal.ZERO;
  /**
   * 本次使用金额
   */
  private BigDecimal usedFee = BigDecimal.ZERO;
  /**
   * 条目当前可用余额
   */
  private BigDecimal availableFee = BigDecimal.ZERO;

  /**
   * 冗余字段：销售公司编码
   */
  @ApiModelProperty(value = "冗余字段：销售公司编码")
  private String saleCompanyCode;

  /**
   * 冗余字段：销售公司名称
   */
  @ApiModelProperty(value = "冗余字段：销售公司名称")
  private String saleCompanyName;

  /**
   * 冗余字段：客户编码
   */
  @ApiModelProperty(value = "冗余字段：客户编码")
  private String cusCode;

  /**
   * 调整原因
   */
  @ApiModelProperty(value = "调整原因")
  private String adjustReason;


  /**
   * 调整原因描述
   */
  @ApiModelProperty(value = "调整原因描述")
  @CrmDict(typeCode = "pool_fee_adjust_reason", dictCodeField = "adjustReason")
  private String adjustReasonName;
  /**
   * 上账原因
   */
  @ApiModelProperty(value = "上账原因")
  private String onAccountReason;
  /**
   * 上账原因描述
   */
  @ApiModelProperty(value = "上账原因描述")
  @CrmDict(typeCode = "pool_fee_adjust_reason", dictCodeField = "onAccountReason")
  private String onAccountReasonName;
  /**
   * 货补费用池唯一约束字典编码
   */
  @ApiModelProperty(value = "货补费用池唯一约束字典编码")
  private String uniqueDictCode;

  /**
   * 费用池操作记录编码
   */
  @ApiModelProperty(value = "费用池操作记录编码")
  private String rebateFeePoolBpmCode;

}

==> crm-commom-vo-1.2.4.15.release.jar: com/biz/crm/nebular/dms/rebatefeepool/RebateFeePoolDetailLogVo.java <==
package com.biz.crm.nebular.dms.rebatefeepool;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmExtVo;
import com.biz.crm.nebular.mdm.CrmFileVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.math.BigDecimal;
import java.util.List;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 折扣费用池条目调整明细VO
 * @Author: chenrong
 * @Date: 2020/11/23 16:53
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel(value = "折扣费用池条目调整明细VO")
public class RebateFeePoolDetailLogVo extends CrmExtVo {

  private static final long serialVersionUID = -4941737089772063724L;

  /**
   * 折扣费用池条目编码
   */
  @ApiModelProperty(value = "折扣费用池条目编码")
  private String rebateFeePoolDetailCode;

  /**
   * 折扣费用池条目调整明细编码
   */
  @ApiModelProperty(value = "折扣费用池条目调整明细编码")
  private String code;

  /**
   * 调整类型
   */
  @ApiModelProperty(value = "调整类型")
  private Integer adjustType;

  @ApiModelProperty(value = "调整类型名称")
  @CrmDict(typeCode="fee_adjust_type",dictCodeField="adjustType")
  private String adjustTypeName;

  /**
   * 业务来源编码
   */
  @ApiModelProperty(value = "业务来源编码")
  private String resourceCode;

  /**
   * 调整金额
   */
  @ApiModelProperty(value = "调整金额")
  private BigDecimal adjustFee = BigDecimal.ZERO;

  /**
   * 支付方式
   */
  @ApiModelProperty(value = "支付方式")
  private Integer payType;

  /**
   * 冗余字段，文件对象集合
   */
  @ApiModelProperty(value = "冗余字段，文件对象集合")
  private List<RebateFeePoolFileVo> files;

  /**
   * 折扣费用池条目
   */
  @ApiModelProperty(value = "折扣费用池条目")
  private RebateFeePoolDetailVo rebateFeePoolDetailVo;

  /**
   * 冻结金额
   */
  @ApiModelProperty(value = "冻结金额")
  private BigDecimal frozenFee = BigDecimal.ZERO;

  /**
   * 冗余字段：折扣费用池编码
   */
  @ApiModelProperty(value = "折扣费用池编码")
  private String rebateFeePoolCode;

  /**
   * 冗余字段：调整类型集合
   */
  @ApiModelProperty(value = "调整类型集合，pc端查报表传参用")
  private List<String> adjustTypes;

  /**
   * 本次上账金额
   */
  private BigDecimal onAccountFee = BigDecimal.ZERO;
  /**
   * 本次使用金额
   */
  private BigDecimal usedFee = BigDecimal.ZERO;
  /**
   * 条目当前可用余额
   */
  private BigDecimal availableFee = BigDecimal.ZERO;

  /**
   * 冗余字段：销售公司编码
   */
  @ApiModelProperty(value = "冗余字段：销售公司编码")
  private String saleCompanyCode;

  /**
   * 冗余字段：销售公司名称
   */
  @ApiModelProperty(value = "冗余字段：销售公司名称")
  private String saleCompanyName;

  /**
   * 冗余字段：客户编码
   */
  @ApiModelProperty(value = "冗余字段：客户编码")
  private String cusCode;

  /**
   * 调整原因
   */
  @ApiModelProperty(value = "调整原因")
  private String adjustReason;


  /**
   * 调整原因描述
   */
  @ApiModelProperty(value = "调整原因描述")
  @CrmDict(typeCode = "pool_fee_adjust_reason", dictCodeField = "adjustReason")
  private String adjustReasonName;
  /**
   * 上账原因
   */
  @ApiModelProperty(value = "上账原因")
  private String onAccountReason;
  /**
   * 上账原因描述
   */
  @ApiModelProperty(value = "上账原因描述")
  @CrmDict(typeCode = "pool_fee_adjust_reason", dictCodeField = "onAccountReason")
  private String onAccountReasonName;
  /**
   * 货补费用池唯一约束字典编码
   */
  @ApiModelProperty(value = "货补费用池唯一约束字典编码")
  private String uniqueDictCode;

  /**
   * 费用池操作记录编码
   */
  @ApiModelProperty(value = "费用池操作记录编码")
  private String rebateFeePoolBpmCode;
  private Integer bpmState ;
  /**
   * 冗余字段：货补费用池冻结明细编码
   */
  private String frozenItemCode;
  /**
   * 冗余字段：解冻金额
   */
  private BigDecimal unfrozenFee = BigDecimal.ZERO;

  /**
   * 冗余字段剩余可解冻金额
   */
  private BigDecimal remainFrozenFee = BigDecimal.ZERO;

}
